@@ -33,31 +33,37 @@ sub j2g {
 
 1;
 __END__
-# Below is the stub of documentation for your module. You better edit it!
+
+#
 
 =head1 NAME
 
-Locale::Hebrew::Calendar - Perl extension for blah blah blah
+Locale::Hebrew::Calendar - Jewish Calendar.
 
 =head1 SYNOPSIS
 
-  use Locale::Hebrew::Calendar;
-  blah blah blah
+use Locale::Hebrew::Calendar;
+
+($d, $m, $y) = Locale::Hebrew::Calendar::g2j($dd, $mm, $yy); # Gregorian
+to Jewish
+
+($d, $m, $y) = Locale::Hebrew::Calendar::j2g($dd, $mm, $yy); # Jewish to
+Gregorian
 
 =head1 DESCRIPTION
 
-Stub documentation for Locale::Hebrew::Calendar was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
+This is an XSUB interface to a code which can be found on seveal main FTP
+servers. I have never contacted the author, but "He who says things in the
+name of their originators brings redemption to the world" - The actual
+code was written by Amos Shapir. (Email unknown).
 
 =head1 AUTHOR
 
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
+Amos Shapir (email unknown).
+XSUB by Ariel Brosh, schop@cpan.org.
 
-=head1 SEE ALSO
-
-perl(1).
+=head1 COPYRIGHT
 
+Tie::Collection is part of the HTPL package. See L<HTML::HTPL>
+ 
 =cut
