@@ -1,5 +1,6 @@
 package HTML::HTPL::Fixed;
 
+use HTML::HTPL::Lib;
 use HTML::HTPL::Result;
 use HTML::HTPL::Txt;
 
@@ -8,6 +9,11 @@ use HTML::HTPL::Txt;
 sub openfixed {
     local($filename, @fields) = @_;
 
+    my $sub;
+    if (UNIVERSAL::isa($fields[0], 'SCALAR')) {
+        $sub = ${shift @fields};
+    }
+    my $class = 'HTML::HTPL::Fixed' . ($sub ? "::$sub" : "");
     my (@cols, @heads);
     foreach (@fields) {
         my ($name, $len) = split(/:/, $_);
@@ -19,7 +25,7 @@ sub openfixed {
 
     &HTML::HTPL::Lib'opendoc($hnd, $filename);
 
-    $orig = new HTML::HTPL::Fixed($hnd, \@heads);
+    $orig = $class->new($hnd, \@heads);
     $result = new HTML::HTPL::Result($orig, @cols);
 
 
@@ -30,7 +36,7 @@ sub readln {
     my ($self, $line) = @_;
     my $re = $self->{'re'};
     my @values = ($line =~ /$re/);
-    my @dummy = map {s/\s+$//;} @values;
+    my @dummy = map {s/[\0\s]+$//;} @values;
     \@values;
 }
 
@@ -39,7 +45,19 @@ sub new {
     my $self = HTML::HTPL::Txt::new($class, $hnd, $fields, "\n");
     my $re = join("", map {"(" . ("." x $_) . ")";} @$lens);
     $self->{'re'} = $re;
+    $self->{'len'} = &HTML::HTPL::Lib::sum(@$lens);
     $self;
 }
 
+package HTML::HTPL::Fixed::IBM;
+@ISA = qw(HTML::HTPL::Fixed);
+
+sub realread {
+    my ($self, $hnd) = @_;
+    my $line;
+    my $len = $self->{'len'};
+    return undef unless (read($hnd, $line, $len) > $len / 2);
+    $line;
+}
+
 1;
